import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/models/rewards_list_response.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/customcard.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/locator.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';
import 'package:loyalty_management_tool/utils/toast_builder.dart';

class RechargeWalletCoins extends StatefulWidget {
  final String title;
  final bool isBothValueRequired;
  final String subTitle;
  final String firstItemHint;
  final String firstItemTag;

  final Widget firstItemIcon;

  final RewardsItem? item;

  final num? giftCash;
  final num? giftCoin;
  final num? redemptionPercentage;
  final num? redemptionCoins;
  final Function(num cash) nextCallBack;

  const RechargeWalletCoins(
      {Key? key,
        this.giftCash,
        this.giftCoin,
        this.redemptionPercentage,
        this.redemptionCoins,
        required this.title,
        this.isBothValueRequired = false,
        required this.subTitle,
        this.item,
        required this.nextCallBack,

        required this.firstItemIcon,
        required this.firstItemHint,
        required this.firstItemTag,})
      : super(key: key);

  @override
  RechargeWalletCoinsState createState() => RechargeWalletCoinsState();
}

class RechargeWalletCoinsState extends State<RechargeWalletCoins> {
  GlobalKey<FormState> formKey = GlobalKey();

  final cashController = TextEditingController();

  late TextStyleElements styleElements;

  @override
  initState() {

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    final cash = TextFormField(
      controller: cashController,
      keyboardType: TextInputType.number,
      style: styleElements
          .subtitle1ThemeScalable(context)
          .copyWith(color: HexColor(AppColors.appColorBlack65)),
      decoration: InputDecoration(
        fillColor: Colors.black12,
        filled: true,
        prefixIcon: widget.firstItemIcon,
        hintText: widget.firstItemHint,
        contentPadding: const EdgeInsets.all(16),
        border: UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
        floatingLabelBehavior: FloatingLabelBehavior.auto,
        labelText: widget.firstItemTag,
      ),
    );


    return Padding(
      padding: const EdgeInsets.all(4.0),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(
                bottom: 30.0, left: 16, right: 16, top: 8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              //Center Row contents horizontally,
              crossAxisAlignment: CrossAxisAlignment.start,
              //Center Row contents vertically,

              children: [
                Expanded(
                  child: Align(
                    alignment: Alignment.center,
                    child: Container(
                      child: Text(
                        widget.title ,
                        textAlign: TextAlign.center,
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(fontWeight: FontWeight.bold),
                      ),
                    ),
                  ),
                ),
                Align(
                  alignment: Alignment.centerRight,
                  child: InkWell(
                    onTap: () {
widget.nextCallBack(77);
                    },
                    child: Container(
                      child: Text(
                        AppLocalizationsRewards.of(context)!.translate("next"),
                        textAlign: TextAlign.center,
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(
                            fontWeight: FontWeight.bold,
                            color: HexColor(AppColors.blueApp)),
                      ),
                    ),
                  ),
                )
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(12),
            child: Text(
              widget.subTitle,
              textAlign: TextAlign.center,
              style: styleElements.captionThemeScalable(context),
            ),
          ),
          Flexible(
              child: Padding(padding: const EdgeInsets.all(8.0), child: cash)),
          const SizedBox(
            width: 20,
          ),

          SizedBox(
            height: MediaQuery.of(context).viewInsets.bottom,
          )
        ],
      ),
    );
  }
}
